# Table of Contents

- [reference-catalog](<./reference-catalog.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Reference Catalog](<./Reference-Catalog.md>)
  - [Overview](<./Reference-Catalog/Overview.md>)
  - [Benefits](<./Reference-Catalog/Benefits.md>)
  - [Available Data](<./Reference-Catalog/Available-Data.md>)
  - [Fact Sheet Attributes](<./Reference-Catalog/Fact-Sheet-Attributes.md>)
  - [Was this page helpful?](<./Reference-Catalog/Was-this-page-helpful.md>)
